@@ -21,7 +21,7 @@ class flagDivisionAsker : public boxAsker
 		flagDivisionAsker(QWidget *parent, KGmap *m, QWidget *w, uint count);
 	
 	protected:
-		bool nextBoxAskerQuestionHook(const QString &division, int i, bool isAnswer) override;
+		bool nextBoxAskerQuestionHook(const division *div, int i, bool isAnswer) override;
 		void setAnswerHook(int userSays) override;
 		QString getQuestionHook() const override;
 		division::askMode askMode() const override { return division::eFlag; }
